@@ -3,7 +3,7 @@ package segments
 import (
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 const (
@@ -86,8 +86,8 @@ func (hg *Mercurial) shouldDisplay() bool {
 }
 
 func (hg *Mercurial) setDir(dir string) {
-	dir = platform.ReplaceHomeDirPrefixWithTilde(hg.env, dir) // align with template PWD
-	if hg.env.GOOS() == platform.WINDOWS {
+	dir = runtime.ReplaceHomeDirPrefixWithTilde(hg.env, dir) // align with template PWD
+	if hg.env.GOOS() == runtime.WINDOWS {
 		hg.Dir = strings.TrimSuffix(dir, `\.hg`)
 		return
 	}
