@@ -5,9 +5,9 @@ import (
 	"testing"
 
 	"github.com/alecthomas/assert"
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 )
 
 func TestSetDir(t *testing.T) {
@@ -21,32 +21,32 @@ func TestSetDir(t *testing.T) {
 			Case:     "In home folder",
 			Expected: "~/sapling",
 			Path:     "/usr/home/sapling/.sl",
-			GOOS:     platform.LINUX,
+			GOOS:     runtime.LINUX,
 		},
 		{
 			Case:     "Outside home folder",
 			Expected: "/usr/sapling/repo",
 			Path:     "/usr/sapling/repo/.sl",
-			GOOS:     platform.LINUX,
+			GOOS:     runtime.LINUX,
 		},
 		{
 			Case:     "Windows home folder",
 			Expected: "~\\sapling",
 			Path:     "\\usr\\home\\sapling\\.sl",
-			GOOS:     platform.WINDOWS,
+			GOOS:     runtime.WINDOWS,
 		},
 		{
 			Case:     "Windows outside home folder",
 			Expected: "\\usr\\sapling\\repo",
 			Path:     "\\usr\\sapling\\repo\\.sl",
-			GOOS:     platform.WINDOWS,
+			GOOS:     runtime.WINDOWS,
 		},
 	}
 	for _, tc := range cases {
-		env := new(mock.MockedEnvironment)
+		env := new(mock.Environment)
 		env.On("GOOS").Return(tc.GOOS)
 		home := "/usr/home"
-		if tc.GOOS == platform.WINDOWS {
+		if tc.GOOS == runtime.WINDOWS {
 			home = "\\usr\\home"
 		}
 		env.On("Home").Return(home)
@@ -100,7 +100,7 @@ func TestSetCommitContext(t *testing.T) {
 		},
 	}
 	for _, tc := range cases {
-		env := new(mock.MockedEnvironment)
+		env := new(mock.Environment)
 		env.On("RunCommand", "sl", []string{"log", "--limit", "1", "--template", SLCOMMITTEMPLATE}).Return(tc.Output, tc.Error)
 		sl := &Sapling{
 			scm: scm{
@@ -145,22 +145,22 @@ func TestShouldDisplay(t *testing.T) {
 			Expected:   true,
 		},
 	}
-	fileInfo := &platform.FileInfo{
+	fileInfo := &runtime.FileInfo{
 		Path:         "/sapling/repo/.sl",
 		ParentFolder: "/sapling/repo",
 		IsDir:        true,
 	}
 	for _, tc := range cases {
-		env := new(mock.MockedEnvironment)
+		env := new(mock.Environment)
 		env.On("HasCommand", "sl").Return(tc.HasSapling)
 		env.On("InWSLSharedDrive").Return(false)
-		env.On("GOOS").Return(platform.LINUX)
+		env.On("GOOS").Return(runtime.LINUX)
 		env.On("Home").Return("/usr/home/sapling")
 		env.On("DirMatchesOneOf", fileInfo.ParentFolder, []string{"/sapling/repo"}).Return(tc.Excluded)
 		if tc.InRepo {
 			env.On("HasParentFilePath", ".sl").Return(fileInfo, nil)
 		} else {
-			env.On("HasParentFilePath", ".sl").Return(&platform.FileInfo{}, errors.New("error"))
+			env.On("HasParentFilePath", ".sl").Return(&runtime.FileInfo{}, errors.New("error"))
 		}
 		sl := &Sapling{
 			scm: scm{
@@ -229,7 +229,7 @@ func TestSetHeadContext(t *testing.T) {
 	bm:sapling-segment
 	`
 	for _, tc := range cases {
-		env := new(mock.MockedEnvironment)
+		env := new(mock.Environment)
 		env.On("RunCommand", "sl", []string{"log", "--limit", "1", "--template", SLCOMMITTEMPLATE}).Return(output, nil)
 		env.On("RunCommand", "sl", []string{"status"}).Return(tc.Output, nil)
 		sl := &Sapling{
