@@ -3,15 +3,15 @@ package segments
 import (
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
 )
 
 func TestSvnEnabledToolNotFound(t *testing.T) {
-	env := new(mock.MockedEnvironment)
+	env := new(mock.Environment)
 	env.On("InWSLSharedDrive").Return(false)
 	env.On("HasCommand", "svn").Return(false)
 	env.On("GOOS").Return("")
@@ -26,12 +26,12 @@ func TestSvnEnabledToolNotFound(t *testing.T) {
 }
 
 func TestSvnEnabledInWorkingDirectory(t *testing.T) {
-	fileInfo := &platform.FileInfo{
+	fileInfo := &runtime.FileInfo{
 		Path:         "/dir/hello",
 		ParentFolder: "/dir",
 		IsDir:        true,
 	}
-	env := new(mock.MockedEnvironment)
+	env := new(mock.Environment)
 	env.On("InWSLSharedDrive").Return(false)
 	env.On("HasCommand", "svn").Return(true)
 	env.On("GOOS").Return("")
@@ -157,7 +157,7 @@ func TestSvnTemplateString(t *testing.T) {
 		props := properties.Map{
 			FetchStatus: true,
 		}
-		env := new(mock.MockedEnvironment)
+		env := new(mock.Environment)
 		tc.Svn.env = env
 		tc.Svn.props = props
 		assert.Equal(t, tc.Expected, renderTemplate(env, tc.Template, tc.Svn), tc.Case)
@@ -193,6 +193,7 @@ R       Moved.File`,
 				Moved:      2,
 				Untracked:  1,
 				Conflicted: 1,
+				Formats:    map[string]string{},
 			}},
 			RefOutput:         "1133",
 			ExpectedRef:       1133,
@@ -206,29 +207,30 @@ R       Moved.File`,
 			StatusOutput: `C       build.cake`,
 			ExpectedWorking: &SvnStatus{ScmStatus: ScmStatus{
 				Conflicted: 1,
+				Formats:    map[string]string{},
 			}},
 			ExpectedChanged:   true,
 			ExpectedConflicts: true,
 		},
 		{
 			Case:            "no change",
-			ExpectedWorking: &SvnStatus{ScmStatus: ScmStatus{}},
+			ExpectedWorking: &SvnStatus{ScmStatus: ScmStatus{Formats: map[string]string{}}},
 			ExpectedChanged: false,
 		},
 		{
 			Case:            "not an integer ref",
-			ExpectedWorking: &SvnStatus{ScmStatus: ScmStatus{}},
+			ExpectedWorking: &SvnStatus{ScmStatus: ScmStatus{Formats: map[string]string{}}},
 			ExpectedChanged: false,
 			RefOutput:       "not an integer",
 		},
 	}
 	for _, tc := range cases {
-		fileInfo := &platform.FileInfo{
+		fileInfo := &runtime.FileInfo{
 			Path:         "/dir/hello",
 			ParentFolder: "/dir",
 			IsDir:        true,
 		}
-		env := new(mock.MockedEnvironment)
+		env := new(mock.Environment)
 		env.On("InWSLSharedDrive").Return(false)
 		env.On("IsWsl").Return(false)
 		env.On("HasCommand", "svn").Return(true)
@@ -260,3 +262,44 @@ R       Moved.File`,
 		assert.Equal(t, tc.ExpectedConflicts, s.Working.HasConflicts(), tc.Case)
 	}
 }
+
+func TestRepo(t *testing.T) {
+	cases := []struct {
+		Case     string
+		Repo     string
+		Expected string
+	}{
+		{
+			Case:     "No repo",
+			Repo:     "",
+			Expected: "",
+		},
+		{
+			Case:     "Repo with trailing slash",
+			Repo:     "http://example.com/",
+			Expected: "example.com",
+		},
+		{
+			Case:     "Repo without trailing slash",
+			Repo:     "http://example.com",
+			Expected: "example.com",
+		},
+		{
+			Case:     "Repo with a path",
+			Repo:     "http://example.com/test/repo",
+			Expected: "repo",
+		},
+	}
+	for _, tc := range cases {
+		env := new(mock.Environment)
+		env.On("RunCommand", "svn", []string{"info", "", "--show-item", "repos-root-url"}).Return(tc.Repo, nil)
+		s := &Svn{
+			scm: scm{
+				env:     env,
+				command: SVNCOMMAND,
+			},
+		}
+
+		assert.Equal(t, tc.Expected, s.Repo(), tc.Case)
+	}
+}
